@@ -154,7 +154,7 @@ class jDocument(Sequence):
         if self._type == CONST_TYPE_ARRAY:
             self.removeDocs(position=item)
         else:
-            self.removeAttrib(attribute=item)
+            self.removeAttrib(item)
 
     def __contains__(self, item):
         """
@@ -325,7 +325,7 @@ class jDocument(Sequence):
         q = 0
         if isinstance(attribute, list):
             for at in attribute:
-                q += self.removeAttrib(attribute=at)
+                q += self.removeAttrib(at)
             return q
 
         # if the Json document is an object
@@ -357,7 +357,7 @@ class jDocument(Sequence):
         q = 0
         for obj in self:
             # removes the attribute on each object in the list
-            q += obj.removeAttrib(attribute=attribute)
+            q += obj.removeAttrib(attribute)
 
         return q
 
@@ -694,19 +694,19 @@ class jDocument(Sequence):
             obj = item
             if item.type == CONST_TYPE_ARRAY:
                 # it is a list
-                list(self._jdata).extend(item.value())
+                self._jdata.extend(item.value())
             else:
                 # it is a dict
-                list(self._jdata).append(item.value())
+                self._jdata.append(item.value())
             # endif --
 
         elif isinstance(item, dict):
             obj = jDocument(item)
-            list(self._jdata).append(item)
+            self._jdata.append(item)
 
         elif isinstance(item, list):
             obj = jDocument(item)
-            list(self._jdata).extend(item)
+            self._jdata.extend(item)
 
         else:
             raise Exception(CONST_ERR_ITEM)
@@ -779,7 +779,7 @@ class jDocument(Sequence):
             # exclui os elementos listados
             for i in reversed(range(len(lstRemove))):
                 idel = lstRemove[i - 1]
-                list(self._jdata).remove(idel)
+                self._jdata.remove(idel)
             # endfor --
 
             return len(lstRemove)
@@ -980,7 +980,7 @@ class jDocument(Sequence):
                 # endif --
 
                 if not self._findDocs_flagMacros:
-                    if ruleExpr != str(valAttr):
+                    if str(ruleExpr) != str(valAttr):
                         return False
                     # endif --
 
@@ -1042,12 +1042,12 @@ class jDocument(Sequence):
 
         if isinstance(attribute, str):
             # foi informado apenas o nome do atributo
-            list(self._jdata).sort(key=lambda e: (not e[attribute], e[attribute]))
+            self._jdata.sort(key=lambda e: (not e[attribute], e[attribute]))
 
         else:
             # foi informado um dicionário com o nome do atributo e a sequência (0 ou 1)
             for sortAttrib, order in attribute.items():
-                list(self._jdata).sort(reverse=(True if order != 1 else False), key=lambda e: (not e[sortAttrib], e[sortAttrib]))
+                self._jdata.sort(reverse=(True if order != 1 else False), key=lambda e: (not e[sortAttrib], e[sortAttrib]))
 
         return self
 
